==> openflowplugin-extension-nicira-0.8.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/FlowModCopyFieldIntoFieldCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.FlowModSpec;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.copy.field.into.field._case.FlowModCopyFieldIntoField;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case flow-mod-copy-field-into-field-case {
 *   container flow-mod-copy-field-into-field {
 *     leaf flow-mod-num-bits {
 *       type uint16;
 *     }
 *     leaf src-field {
 *       type uint32;
 *     }
 *     leaf src-ofs {
 *       type uint16;
 *     }
 *     leaf dst-field {
 *       type uint32;
 *     }
 *     leaf dst-ofs {
 *       type uint16;
 *     }
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-copy-field-into-field-case</i>
 *
 */
public interface FlowModCopyFieldIntoFieldCase
    extends
    DataObject,
    Augmentable<FlowModCopyFieldIntoFieldCase>,
    FlowModSpec
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("flow-mod-copy-field-into-field-case");

    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.copy.field.into.field._case.FlowModCopyFieldIntoField</code> <code>flowModCopyFieldIntoField</code>, or <code>null</code> if not present
     */
    @Nullable FlowModCopyFieldIntoField getFlowModCopyFieldIntoField();

}

==> openflowplugin-extension-nicira-0.10.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/FlowModCopyFieldIntoFieldCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec;
import java.lang.Class;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.FlowModSpec;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.copy.field.into.field._case.FlowModCopyFieldIntoField;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case flow-mod-copy-field-into-field-case {
 *   container flow-mod-copy-field-into-field {
 *     leaf flow-mod-num-bits {
 *       type uint16;
 *     }
 *     leaf src-field {
 *       type uint32;
 *     }
 *     leaf src-ofs {
 *       type uint16;
 *     }
 *     leaf dst-field {
 *       type uint32;
 *     }
 *     leaf dst-ofs {
 *       type uint16;
 *     }
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-copy-field-into-field-case</i>
 *
 */
public interface FlowModCopyFieldIntoFieldCase
    extends
    DataObject,
    Augmentable<FlowModCopyFieldIntoFieldCase>,
    FlowModSpec
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("flow-mod-copy-field-into-field-case");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.FlowModCopyFieldIntoFieldCase> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.FlowModCopyFieldIntoFieldCase.class;
    }
    
    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.copy.field.into.field._case.FlowModCopyFieldIntoField</code> <code>flowModCopyFieldIntoField</code>, or <code>null</code> if not present
     */
    @Nullable FlowModCopyFieldIntoField getFlowModCopyFieldIntoField();

}
